@@ -31,8 +31,8 @@ type onepasswordAccount struct {
 }
 
 type onepasswordConfig struct {
-	Command       string
-	Prompt        bool
+	Command       string `json:"command" mapstructure:"command" yaml:"command"`
+	Prompt        bool   `json:"prompt" mapstructure:"prompt" yaml:"prompt"`
 	version       *semver.Version
 	versionErr    error
 	environFunc   func() []string
@@ -367,7 +367,7 @@ func (c *Config) onepasswordOutput(args *onepasswordArgs, withSessionToken withS
 
 func (c *Config) onepasswordReadTemplateFunc(url string, args ...string) string {
 	onepasswordArgs := &onepasswordArgs{
-		args: []string{"read", url},
+		args: []string{"read", "--no-newline", url},
 	}
 
 	switch len(args) {
