@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"encoding/hex"
+	"encoding/json"
 	"errors"
 	"fmt"
 	"io"
@@ -96,6 +97,29 @@ func (c *Config) commentTemplateFunc(prefix, s string) string {
 	return builder.String()
 }
 
+func (c *Config) deleteValueAtPathTemplateFunc(path string, dict map[string]any) any {
+	keys, lastKey, err := keysFromPath(path)
+	if err != nil {
+		panic(err)
+	}
+
+	currentMap := dict
+	for _, key := range keys {
+		value, ok := currentMap[key]
+		if !ok {
+			return dict
+		}
+		nestedMap, ok := value.(map[string]any)
+		if !ok {
+			return dict
+		}
+		currentMap = nestedMap
+	}
+	delete(currentMap, lastKey)
+
+	return dict
+}
+
 func (c *Config) eqFoldTemplateFunc(first, second string, more ...string) bool {
 	if strings.EqualFold(first, second) {
 		return true
@@ -289,6 +313,11 @@ func (c *Config) outputTemplateFunc(name string, args ...string) string {
 	return string(output)
 }
 
+func (c *Config) pruneEmptyDictsTemplateFunc(dict map[string]any) map[string]any {
+	pruneEmptyMaps(dict)
+	return dict
+}
+
 func (c *Config) quoteListTemplateFunc(list []any) []string {
 	result := make([]string, 0, len(list))
 	for _, elem := range list {
@@ -385,6 +414,34 @@ func (c *Config) toIniTemplateFunc(data map[string]any) string {
 	return builder.String()
 }
 
+//nolint:revive,stylecheck
+func (c *Config) toPrettyJsonTemplateFunc(args ...any) string {
+	var (
+		indent = "  "
+		value  any
+	)
+	switch len(args) {
+	case 1:
+		value = args[0]
+	case 2:
+		var ok bool
+		indent, ok = args[0].(string)
+		if !ok {
+			panic(fmt.Errorf("arg 1: expected a string, got a %T", args[0]))
+		}
+		value = args[1]
+	default:
+		panic(fmt.Errorf("expected 1 or 2 arguments, got %d", len(args)))
+	}
+	var builder strings.Builder
+	encoder := json.NewEncoder(&builder)
+	encoder.SetIndent("", indent)
+	if err := encoder.Encode(value); err != nil {
+		panic(err)
+	}
+	return builder.String()
+}
+
 func (c *Config) toTomlTemplateFunc(data any) string {
 	toml, err := chezmoi.FormatTOML.Marshal(data)
 	if err != nil {
@@ -564,6 +621,21 @@ func needsQuote(s string) bool {
 	return false
 }
 
+// pruneEmptyMaps prunes all empty maps from m and returns if m is now empty
+// itself.
+func pruneEmptyMaps(m map[string]any) bool {
+	for key, value := range m {
+		nestedMap, ok := value.(map[string]any)
+		if !ok {
+			continue
+		}
+		if pruneEmptyMaps(nestedMap) {
+			delete(m, key)
+		}
+	}
+	return len(m) == 0
+}
+
 func sortedKeys[K constraints.Ordered, V any](m map[K]V) []K {
 	keys := maps.Keys(m)
 	slices.Sort(keys)
